/*-----------------------------------------------------------------
   File: spROM.sv
   creates a synchronous single-port rom.
   Width, depth and Initialization file passed as parameters
-----------------------------------------------------------------*/
`timescale 1 ps / 1 ps


module spROM
 #(parameter int unsigned width = 8,
   parameter int unsigned depth = 8,
   parameter intFile = "dummy.mif",
   localparam int unsigned addrBits = $clog2(depth)
      )
 (
 input  logic                      CLK,
 input  logic [addrBits-1:0]       ADDRESS,
 output logic [width-1:0]          DATAOUT
);

   logic [width-1:0] rom [0:depth-1];
   
   
   // initialise ROM contents
   initial begin
     $readmemh(intFile,rom);
   end
   
 
   
always_ff @ (posedge CLK)
begin
  DATAOUT <= rom[ADDRESS];
end



endmodule : spROM
/*-----------------------------------------------------------------
   End of File: spROM.sv
-----------------------------------------------------------------*/
